# mehr

[![Tests](https://github.com/Moraxno/py-mehr/actions/workflows/tests.yml/badge.svg)](https://github.com/Moraxno/py-mehr/actions/workflows/tests.yml)

Python package hosting toolboxes and helper functions.
